@@ -294,12 +294,17 @@ class List(Window):
     # allow inherited classes to override index setting behavior
     def _set_index(self, index):
         # do bounds checking
-        if index >= len(self.windows):
+        if index is None:
+            pass
+        elif index >= len(self.windows):
             index = len(self.windows) - 1
         elif index < 0:
             index = 0
         self._index = index
-        self.current_window = self.windows[index]
+        if index is None:
+            self.current_window = None
+        else:
+            self.current_window = self.windows[index]
 
     @index.setter
     def index(self, index):
@@ -309,6 +314,7 @@ class List(Window):
         self.windows.append(window)
 
     def clear(self):
+        self.index = None
         self.windows = []
 
     def render(self, size):
@@ -438,20 +444,28 @@ class Scrollable(Window):
 class Text(Window):
     text = ''
     style = ''
+    indent = ''
 
-    def __init__(self, text, style=''):
+    def __init__(self, text, style='', indent=''):
         self.text = text
         self.style = style
+        self.indent = indent
 
     def render(self, size):
         text = self.text
         texts = text.split('\n')
         w,h = size
         lines = []
+        newline = True
         while texts and (len(lines) < h if h else True):
-            lines.append(texts[0][:w])
+            if newline:
+                lines.append(texts[0][:w])
+            else:
+                lines.append(self.indent + texts[0][:w - len(self.indent)])
             texts[0] = texts[0][w:]
+            newline = False
             if not texts[0]:
+                newline = True
                 texts.pop(0)
         # pad everything out
         lines = [line + ' ' * (w - len(line)) for line in lines]
